pub struct LibQCbKemProvider { /* private fields */ }Expand description
lib-Q Classical McEliece KEM provider implementation
This provider implements KEM operations for Classical McEliece, including key generation, encapsulation, and decapsulation with proper security validation and algorithm routing.
Implementations
Sourceimpl LibQCbKemProvider
impl LibQCbKemProvider
Sourcepub fn new() -> Result<LibQCbKemProvider, Error>
pub fn new() -> Result<LibQCbKemProvider, Error>
Sourcepub fn security_validator(&self) -> &SecurityValidator
pub fn security_validator(&self) -> &SecurityValidator
Get the security validator
Sourcepub fn security_validator_mut(&mut self) -> &mut SecurityValidator
pub fn security_validator_mut(&mut self) -> &mut SecurityValidator
Get mutable access to the security validator
This method is provided for testing scenarios where entropy validation needs to be disabled for deterministic testing. Use with caution in production.