pub struct SignatureContext { /* private fields */ }Expand description
Signature context for digital signature operations
Implementations
Sourceimpl SignatureContext
impl SignatureContext
Sourcepub fn new() -> SignatureContext
pub fn new() -> SignatureContext
Create a new signature context with no provider
Sourcepub fn with_provider(provider: Box<dyn CryptoProvider>) -> SignatureContext
pub fn with_provider(provider: Box<dyn CryptoProvider>) -> SignatureContext
Create a new signature context with a provider
Sourcepub fn with_default_provider() -> SignatureContext
pub fn with_default_provider() -> SignatureContext
Create a new signature context with the default provider
Sourcepub fn set_provider(&mut self, provider: Box<dyn CryptoProvider>)
pub fn set_provider(&mut self, provider: Box<dyn CryptoProvider>)
Set the cryptographic provider
Sourcepub fn provider(&self) -> Option<&dyn CryptoProvider>
pub fn provider(&self) -> Option<&dyn CryptoProvider>
Get the current provider
Sourcepub fn generate_keypair(
&mut self,
algorithm: Algorithm,
randomness: Option<&[u8]>,
) -> Result<SigKeypair, Error>
pub fn generate_keypair( &mut self, algorithm: Algorithm, randomness: Option<&[u8]>, ) -> Result<SigKeypair, Error>
Generate a keypair for the specified algorithm
Sourcepub fn sign(
&self,
algorithm: Algorithm,
secret_key: &SigSecretKey,
message: &[u8],
randomness: Option<&[u8]>,
) -> Result<Vec<u8>, Error>
pub fn sign( &self, algorithm: Algorithm, secret_key: &SigSecretKey, message: &[u8], randomness: Option<&[u8]>, ) -> Result<Vec<u8>, Error>
Sign a message using the given secret key
Sourcepub fn verify(
&self,
algorithm: Algorithm,
public_key: &SigPublicKey,
message: &[u8],
signature: &[u8],
) -> Result<bool, Error>
pub fn verify( &self, algorithm: Algorithm, public_key: &SigPublicKey, message: &[u8], signature: &[u8], ) -> Result<bool, Error>
Verify a signature for the given message and public key
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Check if the context is initialized