pub struct CircuitAir<F>where
F: Field,{ /* private fields */ }Expand description
AIR implementation for an arithmetic circuit
This converts a circuit into an AIR that can be used with STARK proving. The trace represents all wire values, with one row containing all wire values.
Implementations
Sourceimpl<F> CircuitAir<F>where
F: Field,
impl<F> CircuitAir<F>where
F: Field,
Sourcepub fn new(circuit: ArithmeticCircuit<F>) -> CircuitAir<F>
pub fn new(circuit: ArithmeticCircuit<F>) -> CircuitAir<F>
Create a new CircuitAir from an ArithmeticCircuit
Sourcepub fn circuit(&self) -> &ArithmeticCircuit<F>
pub fn circuit(&self) -> &ArithmeticCircuit<F>
Get a reference to the underlying circuit
Sourcepub fn generate_trace(
&self,
witness: &[F],
public: &[F],
) -> Result<DenseMatrix<F>, Error>
pub fn generate_trace( &self, witness: &[F], public: &[F], ) -> Result<DenseMatrix<F>, Error>
Generate an execution trace from witness values
The witness values should include all wire values in the circuit. Wire indices 0..witness_size are witness wires, indices witness_size..witness_size+public_input_size are public inputs, and remaining indices are intermediate wires.
Arguments
witness- Private witness values (witness wires)public- Public input values
Returns
A RowMajorMatrix containing the trace, or an error if validation fails